@@ -8,6 +8,10 @@ import (
 	"{{GOLANG_MODULE}}/internal/query"
 )
 
+func init() {
+	AddRouteRegistrar(GetAppDescription)
+}
+
 func GetAppDescription(router fiber.Router) {
 	router.Get("/app/description", func(c *fiber.Ctx) error {
 		return SendJSON(c, query.GetAppDescription())
