@@ -1,14 +1,15 @@
 {{SLASH_COMMENTS}}
 
+#include "core.h"
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDateTime>
-#include <QDebug>
 #include <QDir>
 #include <QFileInfo>
 #include <QFontDatabase>
 #include <QMutex>
 #include <QQmlApplicationEngine>
+#include <QQmlContext>
 #include <QSettings>
 #include <QTextCodec>
 #include <QTextStream>
@@ -65,8 +66,12 @@ int main(int argc, char *argv[]) {
     QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #endif
     QApplication app(argc, argv);
-    QCoreApplication::setApplicationName("{{APP_NAME}}");
-    QCoreApplication::setApplicationVersion("0.0.1");
+
+    // 告知程序 QML Settings 的具体位置，确保程序能够读到
+    QApplication::setOrganizationName("Toolkit-Py");
+    QApplication::setOrganizationDomain("Toolkit-Py.com");
+    QApplication::setApplicationName("{{APP_NAME}}");
+    QApplication::setApplicationVersion("0.0.1");
 
 #if (QT_VERSION <= QT_VERSION_CHECK(5, 0, 0))
 #if _MSC_VER
@@ -82,16 +87,23 @@ int main(int argc, char *argv[]) {
     QTextCodec::setCodecForLocale(codec);
 #endif
 
-    // TODO print directly when debug
-    qInstallMessageHandler(logMessageHandler);
-
     // Parses the command line arguments
     QCommandLineParser parser;
-    QCommandLineOption configFileOption("c", "Path to config file");
-    parser.setApplicationDescription("{{APP_NAME}} Description");
+    parser.setApplicationDescription("Qml Javascript Example Description");
     parser.addHelpOption();
     parser.addVersionOption();
+    QCommandLineOption configFileOption("c", "Path to config file", "settings.ini");
     parser.addOption(configFileOption);
+    QCommandLineOption debugFlag("D", "Enable debug output to console");
+    parser.addOption(debugFlag);
+    parser.process(app);
+
+    bool debugMode = false;
+    if (parser.isSet(debugFlag)) {
+        debugMode = true;
+    } else {
+        qInstallMessageHandler(logMessageHandler);
+    }
 
     QString fileName = "settings.ini";
     if (parser.isSet(configFileOption)) { fileName = parser.value(configFileOption); }
@@ -101,18 +113,53 @@ int main(int argc, char *argv[]) {
     settings->setIniCodec("UTF-8");
 
     if (!fi.isFile()) {
+        // 普通键值对
         settings->setValue("Remote/Host", "localhost");
         settings->setValue("Remote/Port", "9876");
+        settings->setValue("Remote/BasePath", "/api/v1");
+
+        // 列表
+        QList<QString> specialties = {"计算机", "通信工程", "信息网络", "软件工程", "物联网"};
+        settings->beginWriteArray("Specialty");
+        for (int i = 0; i < specialties.size(); i++) {
+            settings->setArrayIndex(i);
+            settings->setValue("specialty", specialties[i]);
+        }
+        settings->endArray();
+
+        // 对象列表
+        struct Account {
+            QString username;
+            QString password;
+        };
+        QList<Account> accounts = {
+                {"user1", "password1"},
+                {"user2", "password2"},
+                {"user3", "password3"}};
+        settings->beginWriteArray("Accounts");
+        for (int i = 0; i < accounts.size(); i++) {
+            settings->setArrayIndex(i);
+            settings->setValue("username", accounts[i].username);
+            settings->setValue("password", accounts[i].password);
+        }
+        settings->endArray();
     }
 
     // Add fonts
-    QFontDatabase::addApplicationFont("assets/fonts/Alibaba-PuHuiTi-Regular.ttf");
-    QFontDatabase::addApplicationFont("assets/fonts/Alibaba-PuHuiTi-Bold.ttf");
-    QFontDatabase::addApplicationFont("assets/fonts/Alibaba-PuHuiTi-Heavy.ttf");
-    QFontDatabase::addApplicationFont("assets/fonts/Alibaba-PuHuiTi-Light.ttf");
-    QFontDatabase::addApplicationFont("assets/fonts/Alibaba-PuHuiTi-Regular.ttf");
+    // QFontDatabase::addApplicationFont("assets/fonts/Alibaba-PuHuiTi-Regular.ttf");
+    // QFontDatabase::addApplicationFont("assets/fonts/Alibaba-PuHuiTi-Bold.ttf");
+    // QFontDatabase::addApplicationFont("assets/fonts/Alibaba-PuHuiTi-Heavy.ttf");
+    // QFontDatabase::addApplicationFont("assets/fonts/Alibaba-PuHuiTi-Light.ttf");
+    // QFontDatabase::addApplicationFont("assets/fonts/Alibaba-PuHuiTi-Regular.ttf");
+
+    Core *core = new Core();
+    core->InitConfig(settings);
+    core->DebugMode = debugMode;
 
     QQmlApplicationEngine engine;
+
+    engine.rootContext()->setContextProperty("core", core);
+
     const QUrl url("qrc:/main.qml");
     QObject::connect(
             &engine, &QQmlApplicationEngine::objectCreated,
@@ -123,5 +170,7 @@ int main(int argc, char *argv[]) {
             Qt::QueuedConnection);
     engine.load(url);
 
+    QObject::connect(&app, SIGNAL(aboutToQuit()), core, SLOT(onExit()));
+
     return QApplication::exec();
 }
